@@ -1,5 +1,5 @@
 /*****************************************************************************
- * application.cpp - QStarDict, a StarDict clone written with using Qt       *
+ * application.cpp - QStarDict, a StarDict clone written using Qt            *
  * Copyright (C) 2008 Alexander Rodin                                        *
  *                                                                           *
  * This program is free software; you can redistribute it and/or modify      *
@@ -23,6 +23,7 @@
 #include <QLibraryInfo>
 #include <QLocale>
 #include <QTranslator>
+#include <QStringList>
 #endif // QSTARDICT_WITH_TRANSLATIONS
 #include "dictcore.h"
 #include "mainwindow.h"
@@ -41,11 +42,24 @@ Application::Application(int &argc, char **argv)
 {
     setOrganizationName("qstardict");
     setApplicationName("qstardict");
+
+    #ifndef MAEMO
     setQuitOnLastWindowClosed(false);
+    #endif // MAEMO
+
+    #ifndef MAEMO
+    setQuitOnLastWindowClosed(true);
+    #endif // MAEMO
 
 #ifdef QSTARDICT_WITH_TRANSLATIONS
     m_translator = new QTranslator;
+#ifdef Q_WS_MAC
+    QString binPath = QCoreApplication::applicationDirPath();
+    // navigate through mac's bundle tree structore
+    m_translator->load("qstardict-" + QLocale::system().name(), binPath + "/../i18n/");
+#else
     m_translator->load("qstardict-" + QLocale::system().name(), QSTARDICT_TRANSLATIONS_DIR);
+#endif
     installTranslator(m_translator);
     m_qtTranslator = new QTranslator;
     m_qtTranslator->load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
@@ -56,9 +70,14 @@ Application::Application(int &argc, char **argv)
     m_popupWindow = new PopupWindow;
     m_popupWindow->setDict(m_dictCore);
     m_speaker = new Speaker;
+    #ifndef MAEMO
+    m_trayIcon = new TrayIcon;
+    #endif // MAEMO
     m_mainWindow = new MainWindow;
     m_mainWindow->setDict(m_dictCore);
-    m_trayIcon = new TrayIcon;
+    #ifdef MAEMO
+    m_mainWindow->setVisible(true);
+    #endif // MAEMO
 #ifdef QSTARDICT_WITH_DBUS
     m_dbusAdaptor = new DBusAdaptor(m_mainWindow);
 #endif // QSTARDICT_WITH_DBUS
@@ -66,7 +85,9 @@ Application::Application(int &argc, char **argv)
 
 Application::~Application()
 {
+    #ifndef MAEMO
     delete m_trayIcon;
+    #endif // MAEMO
     delete m_mainWindow;
     delete m_popupWindow;
     delete m_speaker;
@@ -81,10 +102,23 @@ Application::~Application()
 
 int Application::exec()
 {
-    m_trayIcon->show();
+    QString text = commandLineText();
+    if (text != QString::null)
+        m_mainWindow->showTranslation(text);
     return QApplication::exec();
 }
 
+QString Application::commandLineText()
+{
+    QStringList args(arguments());
+    for(int i = 1; i < args.count(); ++i)
+    {
+        if(! args.at(i).startsWith('-'))
+            return args.at(i);
+    }
+    return QString::null;
+}
+
 }
 
 // vim: tabstop=4 softtabstop=4 shiftwidth=4 expandtab cindent textwidth=120 formatoptions=tc
