@@ -1,5 +1,5 @@
 /*****************************************************************************
- * speaker.cpp - QStarDict, a StarDict clone written with using Qt           *
+ * speaker.cpp - QStarDict, a StarDict clone written using Qt                *
  * Copyright (C) 2008 Alexander Rodin                                        *
  *                                                                           *
  * This program is free software; you can redistribute it and/or modify      *
@@ -29,7 +29,7 @@ Speaker::Speaker()
 {
     m_speechProcess = new QProcess;
     QSettings settings;
-    m_speechCmd = settings.value("Speaker/speechCmd", "festival --tts").toString();
+    m_speechCmd = settings.value("Speaker/speechCmd", "espeak").toString();
 }
 
 Speaker::~Speaker()
